searchData={"items":[{"type":"module","title":"LiveToast","doc":"LiveComponent for displaying toast messages.","ref":"LiveToast.html"},{"type":"function","title":"LiveToast.group_class_fn/1","doc":"Default class function for the container around the toasts. Override this to change the classes of the toast container element.","ref":"LiveToast.html#group_class_fn/1"},{"type":"function","title":"Examples: - LiveToast.group_class_fn/1","doc":"defmodule MyModule do\n      def group_class_fn(assigns) do\n        [\n          # base classes\n          \"fixed z-50 max-h-screen w-full p-4 md:max-w-[420px] pointer-events-none grid origin-center\",\n          # classes to set container positioning\n          assigns[:corner] == :bottom_left && \"items-end bottom-0 left-0 flex-col-reverse sm:top-auto\",\n          assigns[:corner] == :bottom_right && \"items-end bottom-0 right-0 flex-col-reverse sm:top-auto\",\n          assigns[:corner] == :top_left && \"items-start top-0 left-0 flex-col sm:bottom-auto\",\n          assigns[:corner] == :top_right && \"items-start top-0 right-0 flex-col sm:bottom-auto\"\n        ]\n\n      end\n    end\n\nThen use it in your layout:\n\n \n\nSince this is a public function, you can also write a new function that calls it and extends it's return values.","ref":"LiveToast.html#group_class_fn/1-examples"},{"type":"function","title":"LiveToast.put_toast/4","doc":"Helper function around `send_toast/3` that is useful in pipelines.\nCan be used in a pipeline with either Plug.Conn or LiveView.Socket.\n\nUnlike `send_toast/3`, this function does not expose the UUID of the\nnew toast, so if you need to update the toast after popping it onto\nthe list, you should use `send_toast/3` directly.","ref":"LiveToast.html#put_toast/4"},{"type":"function","title":"Examples - LiveToast.put_toast/4","doc":"iex> put_toast(conn, :info, \"Thank you for logging in!\")\n    %Plug.Conn{...}\n\n    iex> put_toast(socket, :info, \"Thank you for logging in!\")\n    %LiveView.Socket{...}","ref":"LiveToast.html#put_toast/4-examples"},{"type":"function","title":"LiveToast.send_toast/3","doc":"Send a new toast message to the LiveToast component.\n\nReturns the UUID of the new toast message. This UUID can be passed back\nto another call to `send_toast/3` to update the properties of an existing toast.","ref":"LiveToast.html#send_toast/3"},{"type":"function","title":"Examples - LiveToast.send_toast/3","doc":"iex> send_toast(:info, \"Thank you for logging in!\", title: \"Welcome\")\n    \"00c90156-56d1-4bca-a9e2-6353d49c974a\"","ref":"LiveToast.html#send_toast/3-examples"},{"type":"function","title":"LiveToast.toast_class_fn/1","doc":"Implement your own function to override the class of the toasts.","ref":"LiveToast.html#toast_class_fn/1"},{"type":"function","title":"Examples: - LiveToast.toast_class_fn/1","doc":"defmodule MyModule do\n      def toast_class_fn(assigns) do\n        [\n          # base classes\n          \"group/toast z-100 pointer-events-auto relative w-full items-center justify-between origin-center overflow-hidden rounded-lg p-4 shadow-lg border col-start-1 col-end-1 row-start-1 row-end-2\",\n          # start hidden if javascript is enabled\n          \"[@media(scripting:enabled)]:opacity-0 [@media(scripting:enabled){[data-phx-main]_&}]:opacity-100\",\n          # used to hide the disconnected flashes\n          if(assigns[:rest][:hidden] == true, do: \"hidden\", else: \"flex\"),\n          # override styles per severity\n          assigns[:kind] == :info && \"bg-white text-black\",\n          assigns[:kind] == :error && \"!text-red-700 !bg-red-100 border-red-200\"\n        ]\n\n      end\n    end\n\nThen use it in your layout:\n\n     \n\nSince this is a public function, you can also write a new function that calls it and extends it's return values.","ref":"LiveToast.html#toast_class_fn/1-examples"},{"type":"function","title":"LiveToast.toast_group/1","doc":"Renders a group of toasts and flashes.\n\nReplace your `flash_group` with this component in your layout.","ref":"LiveToast.html#toast_group/1"},{"type":"function","title":"Attributes - LiveToast.toast_group/1","doc":"* `flash` (`:map`) (required) - the map of flash messages.\n* `id` (`:string`) - the optional id of flash container. Defaults to `\"toast-group\"`.\n* `connected` (`:boolean`) (required) - whether we're in a liveview or not.\n* `kinds` (`:list`) - the valid severity level kinds. Defaults to `[:info, :error]`.\n* `corner` (`:atom`) - the corner to display the toasts. Defaults to `:bottom_right`.\n* `group_class_fn` (`:any`) - function to override the container classes. Defaults to `&LiveToast.group_class_fn/1`.\n* `toast_class_fn` (`:any`) - function to override the toast classes. Defaults to `&LiveToast.toast_class_fn/1`.\n* `toasts_sync` (`:list`) (required) - toasts that get synchronized when calling `put_toast`.","ref":"LiveToast.html#toast_group/1-attributes"},{"type":"type","title":"LiveToast.component_fn/0","doc":"`Phoenix.Component` that renders a part of the toast message.","ref":"LiveToast.html#t:component_fn/0"},{"type":"type","title":"LiveToast.option/0","doc":"Set of public options to augment the default toast behavior.","ref":"LiveToast.html#t:option/0"},{"type":"opaque","title":"LiveToast.t/0","doc":"Instance of a toast message. Mainly used internally.","ref":"LiveToast.html#t:t/0"},{"type":"module","title":"LiveToast.Components","doc":"This module defines the components used in the rendering of the default toast messages.\nYou can use this as a reference to create your own version of these components.","ref":"LiveToast.Components.html"},{"type":"function","title":"LiveToast.Components.toast/1","doc":"Default toast function. Based on the look and feel of [Sonner](https://sonner.emilkowal.ski/).\n\nYou can use this as a reference to create your own toast component, that can be passed to the `component` option of `LiveToast.send_toast/3`.","ref":"LiveToast.Components.html#toast/1"},{"type":"function","title":"Attributes - LiveToast.Components.toast/1","doc":"* `id` (`:string`) - the optional id of flash container.\n* `flash` (`:map`) - the map of flash messages to display. Defaults to `%{}`.\n* `title` (`:string`) - Defaults to `nil`.\n* `kind` (`:atom`) - used for styling and flash lookup.Must be one of `:info`, or `:error`.\n* `target` (`:any`) - the target for the phx-click event. Defaults to `nil`.\n* `duration` (`:integer`) - the time in milliseconds before the message is automatically dismissed. Defaults to `6000`.\n* `toast_class_fn` (`:any`) (required) - function to override the toast classes.\n* `corner` (`:atom`) (required) - the corner to display the toasts.\n* `icon` (`:any`) - the optional icon to render in the flash message. Defaults to `nil`.\n* `action` (`:any`) - the optional action to render in the flash message. Defaults to `nil`.\n* `component` (`:any`) - the optional component to render the flash message. Defaults to `nil`.\n* Global attributes are accepted. the arbitrary HTML attributes to add to the flash container.","ref":"LiveToast.Components.html#toast/1-attributes"},{"type":"function","title":"Slots - LiveToast.Components.toast/1","doc":"* `inner_block` - the optional inner block that renders the flash message.","ref":"LiveToast.Components.html#toast/1-slots"},{"type":"extras","title":"Live Toast","doc":"# Live Toast\n\n \n     \n     \n \n\n \n\nLive Toast is a drop-in replacement for the flash system in Phoenix/LiveView.","ref":"readme.html"},{"type":"extras","title":"Features - Live Toast","doc":"- **📄 Stackable toast messages:** The flash system limits you to one flash per type. No longer!\n- **📸 Replaces your flash messages:** One drop in component to continue to render your flash messages in the same style as\n    the newer toast system.\n- **💅 Beautiful by design:** Based on the look of the wonderful [Sonner](https://sonner.emilkowal.ski/) library from React.\n- **⚙️ Highly configurable:** Looks good out of the box, but can be changed in pretty much any way you want.\n- **🌍 Simple asset delivery:** `LiveToast` simply ships Tailwind classes and lets your project bundle them up. No CSS\n    drop-in required.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Live Toast","doc":"Add `live_toast` to your list of dependencies in the `mix.exs` of your Phoenix\napplication:\n\n```elixir\ndef deps do\n  [\n    {:live_toast, \"~> 0.8.0\"}\n  ]\nend\n```\n\nNext open up your `app.js` and import/setup the hook.\n\nIf you have a `package.json` file at the top of `assets`, you can add this to it:\n\n```json\n\"dependencies\": {\n  \"live_toast\": \"file:../deps/live_toast\",\n},\n```\n\nAnd then import and set up the bare module:\n\n```javascript\nimport { createLiveToastHook } from 'live_toast'\n\nlet liveSocket = new LiveSocket('/live', Socket, {\n  hooks: {\n    LiveToast: createLiveToastHook()\n  }\n})\n```\n\nOr you can import the file directly:\n\n```javascript\n// this path would be relative to where your app.js happens to be.\nimport { createLiveToastHook } from '../deps/live_toast'\n\nlet liveSocket = new LiveSocket('/live', Socket, {\n    hooks: {\n        LiveToast: createLiveToastHook()\n    }\n})\n```\n\nThen, add `'../deps/live_toast/lib/**/*.*ex'` to your list of paths Tailwind will look for class names, in your\n`tailwind.config.js`:\n\n```javascript\n// assets/tailwind.config.js\n\nmodule.exports = {\n  content: [\n    './js/**/*.js',\n    '../lib/your_app_web.ex',\n    '../lib/your_app_web/**/*.*ex',\n    '../deps/live_toast/lib/**/*.*ex',\n  ]\n}\n```\n\nYour particular file will look different but all you need to do is make sure the last line is there.\n\n> **Note for Umbrella Apps:**\n> If you're using an umbrella application, your paths above may look different. You'll probably have an extra folder in\n> there, so the line you need to add would be more like `\"../../../deps/live_toast/lib/**/*.*ex\"`\n\nFinally, replace your `<.flash_group />` component with the new ` `. It's most likely in your\n`app.html.heex`:\n\n```heex\n<!-- Remove this! -->\n<.flash_group flash={@flash} />\n\n<!-- And replace it with this: -->\n \n\n<%= @inner_content %>\n```\n\nThose three options, `flash`, `connected`, and `toasts_sync` are all required. The library will not function properly if\nyou do not pass them in.\n\n\n> **Note:**\n> As far as I can tell in my testing, this usage of `assigns` in the layout has no negative impact on change tracking.\n\nAnd you're done! Note that it's very important to set `connected` based on whether we're in a LiveView or not. This\ncontrols toast/flash display on non-LiveView pages.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Live Toast","doc":"`LiveToast` will hijack the usual display of your flash messages, so they will continue to work as normal. You can\ncontinue to use flashes as normal, if you want to.\n\nHowever, one of the reasons to *not* use flash messages, is the Phoenix flash system only allows one message for each\nkind of flash. The toast pattern, alternatively, generally allows for multiple messages displayed to the user at at time.\n\nFrom a LiveView, you can now use [`send_toast`](https://hexdocs.pm/live_toast/LiveToast.html#send_toast/3):\n\n> **Note:**\n> Please reference the `Configuration` section below for the available `options`.\n\n```elixir\ndefmodule YourApp.SomeLiveView do\n  def handle_event(\"submit\", _payload, socket) do\n    options = [\n      title: \"Status\"\n    ]\n\n    # you do some thing with the payload, then you want to show a toast, so:\n    LiveToast.send_toast(:info, \"Upload successful.\", options)\n\n    {:noreply, socket}\n  end\nend\n```\n\n> **Note:**\n> `LiveToast` is the top-level module, so there's no need to `alias` or `import` anything.\n\nOr you can use the helper function, [`put_toast`](https://hexdocs.pm/live_toast/LiveToast.html#put_toast/4), similar to how you may use [`put_flash`](https://hexdocs.pm/phoenix/Phoenix.Controller.html#put_flash/3):\n\n```elixir\ndefmodule YourApp.SomeLiveView do\n  def handle_event(\"submit\", _payload, socket) do\n    socket = socket\n    |> LiveToast.put_toast(:info, \"Upload successful.\")\n\n    {:noreply, socket}\n  end\nend\n```\n\n[`put_toast`](https://hexdocs.pm/live_toast/LiveToast.html#put_toast/4) can take a `Phoenix.LiveView.Socket` or a `Plug.Conn`, so you can use the same thing in your live and\nnon-live pages.\n\n```elixir\ndefmodule YourApp.SomeController do\n  def create(conn, _params) do\n    conn\n    |> LiveToast.put_toast(:info, \"Upload successful.\")\n    |> render(:whatever)\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Configuration - Live Toast","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Setting the corner - Live Toast","doc":"You can change which corner the toasts are anchored to by passing the `corner` setting to `toast_group`, one of either `:top_left`, `:top_right`, `:bottom_left`, `:bottom_right`. The default is `:bottom_right`.\n\n```heex\n \n```","ref":"readme.html#setting-the-corner"},{"type":"extras","title":"Internationalization - Live Toast","doc":"You can provide translations for the defaul error toasts by adding the following to your `config.exs`:\n\n```elixir\nconfig :live_toast,\n  gettext_backend: MyApp.Gettext\n```\n\nYou have to create a `live_toast.po` file, inside the `priv/gettext/ /LC_MESSAGES/` folder for each language you want to support.\n\nFor example, if you want to support spanish, you would create the file `live_toast.po` in the `priv/gettext/es/LC_MESSAGES/` folder, with the following content:\n\n```po\nmsgid \"\"\nmsgstr \"\"\n\"Language: es\\n\"\n\"MIME-Version: 1.0\\n\"\n\"Content-Type: text/plain; charset=UTF-8\\n\"\n\"Content-Transfer-Encoding: 8bit\\n\"\n\"Plural-Forms: nplurals=2; plural=(n != 1);\\n\"\n\nmsgid \"We can't find the internet\"\nmsgstr \"Nosotros no podemos encontrar internet\"\n\nmsgid \"Attempting to reconnect\"\nmsgstr \"Intentando reconectar\"\n\nmsgid \"Something went wrong!\"\nmsgstr \"¡Algo salió mal!\"\n\nmsgid \"Hang in there while we get back on track\"\nmsgstr \"Aguanta mientras volvemos a la normalidad\"\n```","ref":"readme.html#internationalization"},{"type":"extras","title":"Function Options - Live Toast","doc":"[`send_toast`](https://hexdocs.pm/live_toast/LiveToast.html#send_toast/3) takes a number of arguments to control it's behavior. They are currently:\n\n- `kind`: The 'level' of this toast. The `component` function can receive this and modify behavior based on severity.\n    the `toast_class_fn` also receives it, and it can be used there to modify styles, for example, making `:info` toasts\n    green and `:error` toasts red.\n- `body`: The primary text of the message.\n- `title`: The optional title of the toast displayed at the top.\n- `icon`: An optional function component that renders next to the title. You can use this with the default toast to display an icon.\n- `action`: An optional function component that renders to the side. You can use this with the default toast to display an action, like a button.\n- `component`: Use this to totally override rendering of the toast. This is expected to be a function component that\n    will receive all of the above options. See [this part of the demo](https://github.com/srcrip/live_toast/blob/fddcd7c51be05ba9997eb300ca920985e98ab583/demo/lib/demo_web/live/home_live.ex#L61) as an example.\n\nNote that if you use more than just `:info` and `:error` in your codebase for flashes, you can augment LiveToast using\nsome of the methods below to support that.","ref":"readme.html#function-options"},{"type":"extras","title":"Custom Classes - Live Toast","doc":"You can define a [custom toast class function](https://hexdocs.pm/live_toast/LiveToast.html#toast_class_fn/1), like so:\n\n```elixir\ndefmodule MyModule do\n  def toast_class_fn(assigns) do\n    [\n      # base classes\n      \"group/toast z-100 pointer-events-auto relative w-full items-center justify-between origin-center overflow-hidden rounded-lg p-4 shadow-lg border col-start-1 col-end-1 row-start-1 row-end-2\",\n      # start hidden if javascript is enabled\n      \"[@media(scripting:enabled)]:opacity-0 [@media(scripting:enabled){[data-phx-main]_&}]:opacity-100\",\n      # used to hide the disconnected flashes\n      if(assigns[:rest][:hidden] == true, do: \"hidden\", else: \"flex\"),\n      # override styles per severity\n      assigns[:kind] == :info && \"bg-white text-black\",\n      assigns[:kind] == :error && \"!text-red-700 !bg-red-100 border-red-200\"\n    ]\n  end\nend\n\n```\n\nAnd then use it to override the default styles:\n\n```heex\n \n```\n\nIf you need to change the classes of the container, there is a similar function parameter called [`group_class_fn`](https://hexdocs.pm/live_toast/LiveToast.html#group_class_fn/1). Reference the documentation and apply the override just as you would `toast_class_fn/1` shown above.","ref":"readme.html#custom-classes"},{"type":"extras","title":"Custom Severity Levels - Live Toast","doc":"New Phoenix projects [use `:info` and `:error`](https://hexdocs.pm/phoenix/controllers.html#flash-messages)\nas the default severity levels for flash messages, so this is likely what you're already using. If you need to add an\nadditional severity level, like `:warning`, you can pass a list of these values to the `kind` attribute:\n\n```heex\n \n```\n\nIf this value is not set, it defaults to `[:info, :error]`.\n\nSetting `kind` will allow these new severity levels to be displayed, but it won't change how they look. To do that, you\nneed to override [`toast_class_fn/1`](https://hexdocs.pm/live_toast/LiveToast.html#toast_class_fn/1). For example:\n\n```elixir\n# Note that this is just the default with one line added to handle the new `:warning` level.\ndef custom_toast_class_fn(assigns) do\n  [\n    # base classes\n    \"bg-white group/toast z-100 pointer-events-auto relative w-full items-center justify-between origin-center overflow-hidden rounded-lg p-4 shadow-lg border col-start-1 col-end-1 row-start-1 row-end-2\",\n    # start hidden if javascript is enabled\n    \"[@media(scripting:enabled)]:opacity-0 [@media(scripting:enabled){[data-phx-main]_&}]:opacity-100\",\n    # used to hide the disconnected flashes\n    if(assigns[:rest][:hidden] == true, do: \"hidden\", else: \"flex\"),\n    # override styles per severity\n    assigns[:kind] == :info && \"text-black\",\n    assigns[:kind] == :error && \"!text-red-700 !bg-red-100 border-red-200\",\n    assigns[:kind] == :warning && \"!text-amber-700 !bg-amber-100 border-amber-200\"\n  ]\nend\n```\n\nThen just make sure you've passed it to the `live_group` component as seen above.","ref":"readme.html#custom-severity-levels"},{"type":"extras","title":"JavaScript Options - Live Toast","doc":"You can also change some options about the LiveView hook when it is initialized. Such as:\n\n```javascript\nimport { createLiveToastHook } from 'live_toast'\n\n// the duration for each toast to stay on screen in ms\nconst duration = 4000\n\n// how many toasts to show on screen at once\nconst maxItems = 3\n\nconst liveToastHook = createLiveToastHook(duration, maxItems)\n\nlet liveSocket = new LiveSocket('/live', Socket, {\n  hooks: { LiveToast: liveToastHook }\n})\n```","ref":"readme.html#javascript-options"},{"type":"extras","title":"Roadmap - Live Toast","doc":"Some of the stuff still to work on:\n\n- [ ] A11y\n- [ ] Further documentation\n- [ ] Even more configuration\n- [ ] Lots of amazing tests\n- [ ] Spring animations\n- [ ] Possibly some way to configure additional severity levels","ref":"readme.html#roadmap"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nNote that the versions prior to `0.6.0` are very unstable.\n\n## [v0.1.0] (2024-03-06)\n\n🚀 Initial release.\n\n## [v0.2.0] (2024-03-08)\n\nBug fixes:\n- JS.Show on the flashes now correctly toggles them to display flex instead of block\n- The component functions properly when used in non-liveviews\n\n## [v0.3.0] (2024-03-12)\n\nBug fixes:\n- Fixing quite a few little problems here and there\n- Adding more configuration\n\n## [v0.4.0] (2024-05-11)\n\nMassive overhaul of look and feel.\n\n## [v0.4.1] (2024-05-11)\n\nDemo repo bug fixing.\n\n## [v0.4.2] (2024-05-15)\n\nTightening up a few bugs found during the creation of the demo.\n\n## [v0.4.3] (2024-05-15)\n\nFix implementation of `send_toast`.\n\n## [v0.5.0] (2024-05-16)\n\nNew Public API.\n\n## [v0.6.0] (2024-05-17)\n\nFixed Hex release. Some files were missing from the build.\n\n## [v0.6.1] (2024-05-18)\n\nRemove a `console.log` from the JS bundle.\n\n## [v0.6.2] (2024-05-19)\n\nReleasing new bundle (meant to compile it in `v0.6.1`).\n\n## [v0.6.3] (2024-05-22)\n\n- Documentation updates.\n\n## [v0.6.4] (2024-07-10)\n\n- More documentation updates.\n- Fixes invalid usage of Phoenix LiveView streams by moving the flashes outside the stream container.\n- Fixes a bit of a visual issue when loading on non LV pages by setting opacity to 0.\n- New feature: arbitrary severity levels other than `:info` and `:error`.\n- Various refactorings and cleanups.\n- Fix required LV version to 0.20.\n- Added proper TypeScript types.\n- Added customization for the container class.\n\n## [v0.7.0] (2024-12-26) 🎄\n\n- Big fix to longstanding issue where toasts don't work properly across navigations: #28\n- Added gettext internationalization from #16 (thanks @elephantoss)\n- A couple other random cleanups and docs changes.\n\n## [v0.8.0] (2024-02-14) ❤️\n\n- Fixed typespecs from #26 (thanks @wkirschbaum)\n- Added `:top_center` and `:bottom_center` positions in #29 (thanks @nallwhy)\n- Feature: infinite duration toasts from #31 (thanks @vanderhoop)\n- Readme fixes in #32\n- Fix earlier weirdness with gettext usage in 0.7.0 in #34 (thanks @neilberkman)\n- Fix docs source ref in #39 (thanks @Flo0807)","ref":"changelog.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}